@@ -5,7 +5,9 @@ from xend_finance.utils.exceptions.handleErrors import BaseError
 from xend_finance.utils.key_address import private_key_to_address
 
 
-def is_cooperative_member(cycle_id: int, private_key: str, provider: str, address: Addresses):
+def is_cooperative_member(
+    cycle_id: int, private_key: str, provider: str, address: Addresses
+):
     """
     > This function checks if the client is a member of the cycle
 
@@ -22,7 +24,9 @@ def is_cooperative_member(cycle_id: int, private_key: str, provider: str, addres
     try:
         client_address = private_key_to_address(provider, private_key)
         contract = getContract(provider, CYCLES, address.CYCLES)
-        member_exist = contract.functions.doesCycleMemberExist(cycle_id, client_address).call()
+        member_exist = contract.functions.doesCycleMemberExist(
+            cycle_id, client_address
+        ).call()
         return {"status": "success", "data": bool(member_exist)}
     except BaseError as e:
         raise BaseError({"status": "error", "message": e})
