@@ -2,7 +2,7 @@
 
 from xend_finance import XendFinance
 
-xend = XendFinance(56,'0x4f6aa0d2c5539e9ccd20953720e5ff4f20a2c96597340921b015b29c5d7b1847', {"env": "mainnet"})
+xend = XendFinance(56,'0x06cce0427cbdd1e46197477124e41e0ba018f3153dc8a60015fdf656c325c011', {"env": "local"})
 
 #  COOPERATIVE
 
@@ -15,7 +15,7 @@ xend = XendFinance(56,'0x4f6aa0d2c5539e9ccd20953720e5ff4f20a2c96597340921b015b29
 #     "max_members": 10
 # }
 # create_cooperate = xend.cooperative.create(args)
-# # print(create_cooperate)
+# print(create_cooperate)
 
 
 # # args = {
@@ -34,13 +34,13 @@ xend = XendFinance(56,'0x4f6aa0d2c5539e9ccd20953720e5ff4f20a2c96597340921b015b29
 # does_member_exist = xend.cooperative.cycle_member_exist(5)
 # print(does_member_exist)
 
-# start_cycle = xend.cooperative.start_cycle(5)
-# print(start_cycle)
+# start_cycle = xend.cooperative.start_cycle(3)
+# print(type(start_cycle))
 
-# withdraw_ongoing_cycle = xend.cooperative.withdraw_from_ongoing_cycle(7)
+# withdraw_ongoing_cycle = xend.cooperative.withdraw_from_ongoing_cycle(1)
 # print(withdraw_ongoing_cycle)
 
-# withdraw_completed_cycle = xend.cooperative.withdraw_completed(10)
+# withdraw_completed_cycle = xend.cooperative.withdraw_completed(1)
 # print(withdraw_completed_cycle)
 
 # create_cooperative_group = xend.cooperative.create_group('test', 'TST')
@@ -66,7 +66,7 @@ xend = XendFinance(56,'0x4f6aa0d2c5539e9ccd20953720e5ff4f20a2c96597340921b015b29
 #     "max_members": 10
 # }
 # create_esusu_cycle = xend.esusu.create_esusu(args)
-# # print(create_esusu_cycle)
+# print(create_esusu_cycle)
 
 # get_esusu_cycles_count = xend.esusu.get_cycles_count()
 # print(get_esusu_cycles_count)
@@ -108,15 +108,15 @@ xend = XendFinance(56,'0x4f6aa0d2c5539e9ccd20953720e5ff4f20a2c96597340921b015b29
 # print(esusu_contributions)
 
 # esusu_cycles_in_group = xend.esusu.cycles_in_group(11)
-# # print(cycles_in_group)
+# print(esusu_cycles_in_group)
 
 
 # # GROUP
 # create_group = xend.group.create('mnt', 'MNT')
 # print(create_group)
 
-# get_single_group = xend.group.get_single_group(3)
-# # print(get_single_group)
+# get_single_group = xend.group.get_single_group(1)
+# print(get_single_group)
 
 # get_groups = xend.group.get_groups()
 # print(get_groups)
@@ -125,7 +125,7 @@ xend = XendFinance(56,'0x4f6aa0d2c5539e9ccd20953720e5ff4f20a2c96597340921b015b29
 # print(get_xend_rewards)
 
 # # PERSONAL
-# create_flexible_deposit = xend.personal.flexible_deposit(2)
+# create_flexible_deposit = xend.personal.flexible_deposit("20")
 # print(create_flexible_deposit)
 
 # create_fixed_deposit = xend.personal.fixed_deposit(40, 30)
