@@ -19,6 +19,10 @@ def get_xend_mainnet_addresses():
 
 
 def get_bsc_mainnet_addresses() -> List[Protocols]:
+    """
+    It gets the addresses of the contracts deployed on the BSC mainnet
+    :return: A list of protocols
+    """
     protocols: List[Protocols] = []
     data = get_xend_mainnet_addresses()
     if data and type(data) == list:
@@ -65,4 +69,8 @@ def get_bsc_mainnet_addresses() -> List[Protocols]:
 
 
 def get_layer2_protocols():
+    """
+    > This function returns a list of all the layer 2 protocols that are supported by the tool
+    :return: A list of all the layer 2 protocols
+    """
     return layer_2_assets.layer_assets
