@@ -8,6 +8,20 @@ from xend_finance.utils.exceptions.handleErrors import BaseError
 def get_protocol_essentials(
     protocols: List[Protocols], protocol_name: Union[str, None] = None
 ):
+    """
+    It takes a list of protocols and a protocol name,
+    and returns a dictionary with the addresses, name, and available protocols
+
+    :param protocols: List[Protocols]
+    :type protocols: List[Protocols]
+    :param protocol_name: The name of the protocol you want to use.
+    If you don't specify one, the first protocol in the list will be used
+    :type protocol_name: Union[str, None]
+    :return: A dictionary with the following keys:
+        - addresses: a list of addresses
+        - name: a string
+        - available: a list of lists
+    """
     if protocol_name:
         # filter the protocols by protocol_name
         requested_protocol = list(
@@ -30,6 +44,14 @@ def get_protocol_essentials(
 
 
 def protocol_selector(options: Options):
+    """
+    It takes in the options object and returns the protocol essentials
+    for the protocol name provided in the options object
+
+    :param options: Options
+    :type options: Options
+    :return: The protocol essentials are being returned.
+    """
     protocol_name = options.protocol_name
     environment = options.env
     local_protocol = options.protocols
